@@ -28,7 +28,6 @@ Improvements:
     See TODOs and FIXMEs scattered throughout :-)
 
 """
-
 import datetime
 import sys
 
@@ -42,7 +41,8 @@ from django.db.models import (
     AutoField, BooleanField, DateField, DateTimeField, FileField, ForeignKey,
 )
 from django.db.models.deletion import Collector
-from django.utils.encoding import smart_text, force_text
+from django.utils import timezone
+from django.utils.encoding import force_str, smart_text
 
 from django_extensions.management.utils import signalcommand
 
@@ -69,13 +69,18 @@ def orm_item_locator(orm_obj):
 
     for key in clean_dict:
         v = clean_dict[key]
-        if v is not None and not isinstance(v, (six.string_types, six.integer_types, float, datetime.datetime)):
-            clean_dict[key] = six.u("%s" % v)
+        if v is not None:
+            if isinstance(v, datetime.datetime):
+                v = timezone.make_aware(v)
+                clean_dict[key] = StrToCodeChanger('dateutil.parser.parse("%s")' % v.isoformat())
+            elif not isinstance(v, (six.string_types, six.integer_types, float)):
+                clean_dict[key] = six.u("%s" % v)
 
     output = """ importer.locate_object(%s, "%s", %s, "%s", %s, %s ) """ % (
         original_class, original_pk_name,
         the_class, pk_name, pk_value, clean_dict
     )
+
     return output
 
 
@@ -83,7 +88,7 @@ class Command(BaseCommand):
     help = 'Dumps the data as a customised python script.'
 
     def add_arguments(self, parser):
-        super(Command, self).add_arguments(parser)
+        super().add_arguments(parser)
         parser.add_argument('appname', nargs='+')
         parser.add_argument(
             '--autofield', action='store_false', dest='skip_autofield',
@@ -148,7 +153,7 @@ def get_models(app_labels):
     return models
 
 
-class Code(object):
+class Code:
     """
     A snippet of python script.
     This keeps track of import statements and can be output to a string.
@@ -188,7 +193,7 @@ class ModelCode(Code):
     """ Produces a python script that can recreate data for a given model class. """
 
     def __init__(self, model, context=None, stdout=None, stderr=None, options=None):
-        super(ModelCode, self).__init__(indent=0, stdout=stdout, stderr=stderr)
+        super().__init__(indent=0, stdout=stdout, stderr=stderr)
         self.model = model
         if context is None:
             context = {}
@@ -234,7 +239,7 @@ class InstanceCode(Code):
     def __init__(self, instance, id, context=None, stdout=None, stderr=None, options=None):
         """ We need the instance in question and an id """
 
-        super(InstanceCode, self).__init__(indent=0, stdout=stdout, stderr=stderr)
+        super().__init__(indent=0, stdout=stdout, stderr=stderr)
         self.imports = {}
 
         self.options = options
@@ -395,7 +400,7 @@ class Script(Code):
     """ Produces a complete python script that can recreate data for the given apps. """
 
     def __init__(self, models, context=None, stdout=None, stderr=None, options=None):
-        super(Script, self).__init__(stdout=stdout, stderr=stderr)
+        super().__init__(stdout=stdout, stderr=stderr)
         self.imports = {}
 
         self.models = models
@@ -520,7 +525,7 @@ class Script(Code):
 import os, sys
 from django.db import transaction
 
-class BasicImportHelper(object):
+class BasicImportHelper:
 
     def pre_import(self):
         pass
@@ -608,6 +613,7 @@ from django.contrib.contenttypes.models import ContentType
 
 try:
     import dateutil.parser
+    from dateutil.tz import tzoffset
 except ImportError:
     print("Please install python-dateutil")
     sys.exit(os.EX_USAGE)
@@ -662,7 +668,7 @@ def get_attribute_value(item, field, context, force=False, skip_autofield=True):
 
     # Post file-storage-refactor, repr() on File/ImageFields no longer returns the path
     elif isinstance(field, FileField):
-        return repr(force_text(value))
+        return repr(force_str(value))
 
     # ForeignKey fields, link directly using our stored python variable name
     elif isinstance(field, ForeignKey) and value is not None:
@@ -742,3 +748,12 @@ class SkipValue(Exception):
 
 class DoLater(Exception):
     """ Value could not be parsed or should simply be skipped. """
+
+
+class StrToCodeChanger:
+
+    def __init__(self, string):
+        self.repr = string
+
+    def __repr__(self):
+        return self.repr
