@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
-# Author Igor Támara igor@tamarapatino.org
-# Use this little program as you wish, if you
-# include it in your work, let others know you
-# are using it preserving this note, you have
-# the right to make derivative works, Use it
-# at your own risk.
-# Tested to work on(etch testing 13-08-2007):
-#  Python 2.4.4 (#2, Jul 17 2007, 11:56:54)
-#  [GCC 4.1.3 20070629 (prerelease) (Debian 4.1.2-13)] on linux2
+"""
+Author Igor Támara igor@tamarapatino.org
+Use this little program as you wish, if you
+include it in your work, let others know you
+are using it preserving this note, you have
+the right to make derivative works, Use it
+at your own risk.
+Tested to work on(etch testing 13-08-2007):
+  Python 2.4.4 (#2, Jul 17 2007, 11:56:54)
+  [GCC 4.1.3 20070629 (prerelease) (Debian 4.1.2-13)] on linux2
+"""
 
 import codecs
 import gzip
@@ -40,25 +42,28 @@ tsd = {
 v2c = re.compile(r'varchar\((\d+)\)')
 
 
-def index(fks, id):
-    """Looks for the id on fks, fks is an array of arrays, each array has on [1]
+def find_index(fks, id_):
+    """
+    Look for the id on fks, fks is an array of arrays, each array has on [1]
     the id of the class in a dia diagram.  When not present returns None, else
-    it returns the position of the class with id on fks"""
-    for i, j in fks.items():
-        if fks[i][1] == id:
+    it returns the position of the class with id on fks
+    """
+    for i, _ in fks.items():
+        if fks[i][1] == id_:
             return i
     return None
 
 
 def addparentstofks(rels, fks):
-    """Gets a list of relations, between parents and sons and a dict of
+    """
+    Get a list of relations, between parents and sons and a dict of
     clases named in dia, and modifies the fks to add the parent as fk to get
     order on the output of classes and replaces the base class of the son, to
     put the class parent name.
     """
     for j in rels:
-        son = index(fks, j[1])
-        parent = index(fks, j[0])
+        son = find_index(fks, j[1])
+        parent = find_index(fks, j[0])
         fks[son][2] = fks[son][2].replace("models.Model", parent)
         if parent not in fks[son][0]:
             fks[son][0].append(parent)
@@ -86,10 +91,10 @@ def dia2django(archivo):
                         myname = "\nclass %s(models.Model) :\n" % actclas
                         clases[actclas] = [[], myid, myname, 0]
                     if j.getAttribute("name") == "attributes":
-                        for l in j.getElementsByTagName("dia:composite"):
-                            if l.getAttribute("type") == "umlattribute":
+                        for ll in j.getElementsByTagName("dia:composite"):
+                            if ll.getAttribute("type") == "umlattribute":
                                 # Look for the attribute name and type
-                                for k in l.getElementsByTagName("dia:attribute"):
+                                for k in ll.getElementsByTagName("dia:attribute"):
                                     if k.getAttribute("name") == "name":
                                         nc = k.getElementsByTagName("dia:string")[0].childNodes[0].data[1:-1]
                                     elif k.getAttribute("name") == "type":
@@ -171,7 +176,7 @@ def dia2django(archivo):
     # First we make a list of the classes each classs is related to.
     ordered = []
     for j, k in six.iteritems(clases):
-        k[2] += "\n    def %s(self):\n        return u\"\"\n" % (("__str__" if six.PY3 else "__unicode__"),)
+        k[2] += "\n    def __str__(self):\n        return u\"\"\n"
         for fk in k[0]:
             if fk not in dependclasses:
                 clases[fk][3] += 1
